angular.module('farrago.controllers')
    .controller('FeaturedCtrl', function ($scope, $ionicScrollDelegate, $ionicLoading, $http, $ionicModal, user, comic, util) {


        //Check connection, and load comics
        util.checkConnection();

        //alert('featured page');

        window.plugins.orientationLock.lock("portrait");

        //window.plugins.orientationLock.lock("landscape"); // TODO PORTRAIT MODE

        //Set page id
        document.body.id = 'featured-view';

        if (typeof analytics !== "undefined") {
            analytics.trackView('Featured');
        }

        $scope.user = user.user;
        $scope.comic = comic;

        //Run check to login the user if there is a connection to internet
        //user.loginExisting();

        //If the user is offline hide loading bar
        if (!util.online) {
            //Hide Loading spinner
            document.querySelector('.spinner').classList.remove('show');
        }

        //Initialize Primary Controller Functions
        var initController = function () {
            $http({
                method: 'GET',
                url: BASEURL + 'api/series',
                headers: {
                    "user-token": user.data.token,
                    "user-email": user.data.email
                },
                params: {featured: true, page: 1}
            }).
                success(function (data, status, headers, config) {
                    $scope.comics = data.series;
                    $scope.total = data.series.length;
                    $scope.comicSelected = 0;

                    //Hide Loading spinner
                    document.querySelector('.spinner').classList.remove('show');
                }).
                error(function (data, status, headers, config) {
                    console.log(data);
                    //Hide Loading spinner
                    document.querySelector('.spinner').classList.remove('show');
                });
        }
        //Get Series Details and Popup modal
        $scope.showDetails = function (id, num) {
            //Get element and snag series id, because angular/ionic doesn't want to pass it in through the function.
            if (!id) {
                id = (document.querySelector('#featured .scroll .item-num-' + num)).getAttribute('data-comic-id');
            }
            $http({
                method: 'GET',
                url: BASEURL + 'api/ratings/'+id,
                headers:{
                    "user-token":user.data.token,
                    "user-email":user.data.email
                }
            }).
                success(function(data, status, headers, config) {
                    $scope.seriesAverageRating = data.avgRating;
                    $scope.seriesTotalUsers = data.totalUsers;
                    var rate_per = $scope.seriesAverageRating*20;
                    //alert(' seriesAverageRating '+data.avgRating+' seriesTotalUsers '+data.totalUsers+' rate_per '+rate_per);
                    $('.avg-rating .star-rating i').css({'width':rate_per+'%','opacity':1});
                }).
                error(function(data, status, headers, config) {
                    //alert('error');
                });

            if (typeof $scope.comics !== 'undefined') {
                $scope.series = '';
                $scope.similarSeries = '';
                for (var x = 0, y = $scope.comics.length; x < y; x++) {
                    if ($scope.comics[x].id === id) {
                        $scope.series = $scope.comics[x];
                    }
                }

                //No series data found locally, then grab from server
                if ($scope.series === '') {
                    comic.getSeries({id: id}, function (data) {
                        $scope.series = data.series;
                        //Get similar series to this one
                        comic.getSimilarSeries({id: $scope.series.categories[0].id}, function (data) {
                            $scope.similarSeries = data.series;
                        });

                    });
                } else {
                    //Get similar series to this one
                    comic.getSimilarSeries({id: $scope.series.categories[0].id}, function (data) {
                        $scope.similarSeries = data.series;
                    });

                }

                //Show the modal
                $scope.modal.show();
                $scope.seriesId = id;
                //Add all issues issue to favorites
                $scope.addSeriesToFavorites = function () {
                    comic.addToFavorites($scope.series.issues);
                }
                //Add one issue to favorite
                $scope.addToFavorites = function (issueId) {
                    comic.addToFavorites(issueId);
                }
            }
        };

        //Set item width based on screen size
        $scope.getComicItemWidth = function () {
            return (window.innerWidth > 500) ? window.innerWidth / 3 : window.innerWidth / 2;
        };

        //load more series and display it to the user.
        var loadMorePage = 2;
        $scope.loadSeriesCheck = true;
        $scope.loadMoreSeries = function () {
            if (typeof $scope.comics !== "undefined" && $scope.comics !== "") {
                //Hide Loading spinner
                document.querySelector('.spinner').classList.add('show');

                $http({
                    method: 'GET',
                    url: BASEURL + 'api/series',
                    headers: {
                        "user-token": user.data.token,
                        "user-email": user.data.email
                    },
                    params: {featured: "true", category: user.urlCategoryList(), page: loadMorePage}
                }).
                    success(function (data, status, headers, config) {

                        if (data.series.length > 0) {
                            loadMorePage++;
                            //Merge new comics into array
                            $scope.comics = $scope.comics.concat(data.series);
                            $scope.comicSelected = 0;
                        } else {
                            $scope.loadSeriesCheck = false;
                        }
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        //Hide Loading spinner
                        document.querySelector('.spinner').classList.remove('show');
                    }).
                    error(function (data, status, headers, config) {
                        //Hide Loading spinner
                        document.querySelector('.spinner').classList.remove('show');
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                    });

            } else {
                $scope.$broadcast('scroll.infiniteScrollComplete');
            }
        }


        //Setting up Modal Template for Details
        $ionicModal.fromTemplateUrl('templates/details.html', {
            scope: $scope
        }).then(function (modal) {
            $scope.modal = modal;
            $scope.closeModal();
        });

        //Modal Functions
        $scope.openModal = function () {
            $scope.modal.show();
        };
        $scope.closeModal = function () {
            $scope.modal.hide();
        };
        //Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function () {
            $scope.modal.remove();
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function () {
            // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function () {
            // Execute action
        });


        //If session is not defined await user intialize broadcast to start controller
        if (typeof user.data.token === 'undefined' || typeof user.data.token === undefined) {
            $scope.$on('comicInitialized', initController);
        } else {
            initController();
        }

//Helper filter to remove spaces and lower case any text
    })
    .filter('removeSpacesThenLowercase', function () {
        return function (text) {
            var str = text.replace(/\s+/g, '');
            return str.toLowerCase();
        };
    });